package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@("`0D````````````"`"L````!```````0'(``````````0```````
M`,TP`````@!``#@`!@!``!D`&`````8````%`````````$```````!``0```
M````$`!``````````5`````````!4``````````(`````P````0````````!
MD```````$`&0```````0`9``````````%0`````````5``````````$````!
M````!0`````````````````0`````````!```````````+:$````````MH0`
M`````!````````$````'````````P````````"#`````````(,``````````
M"P@````````/^```````$````````@````8```````#`.```````(,`X````
M```@P#@````````"``````````(```````````@````$````!`````````&H
M```````0`:@``````!`!J``````````8`````````!@`````````!"]L:6)E
M>&5C+VQD+65L9BYS;RXQ``````````@````$`````49R965"4T0```JVF@``
M`&$```!L`````````#X`````````"P````````!A````8````%L`````````
M`````&D`````````2````%\`````````.0```$(````\````$````#@```!-
M````00```$D````````````````````C````7````#`````$`````````#,`
M``!5````+@```&4```!+````"````&L```!F````'0`````````L````````
M`&0`````````+P```&,`````````3P```"H````'````4@```&@```!`````
M1````"<```!8````70```&H`````````,@```"(`````````3```````````
M``````````````!4````1P```#8```!:````8@```"``````````````````
M``!9````-````$,```!7````7@````\`````````$0````8`````````````
M```````Z`````````"$````5`````````"T```!G````````````````````
M````````````````````````````````````````````````````````````
M``````````X`````````````````````````````````````````````````
M```````````````````3````!0```!L````*```````````````-````````
M``````````````````,`````````````````````````*P`````````?````
M``````P````D`````````"8`````````````````````````````````````
M```````````````W````````````````````/P```````````````````!(`
M````````.P``````````````)0`````````>````"0```"D`````````10``
M`"@````9```````````````]````40```#$``````````````#4````8````
M4````!H```!&`````````!0`````````%P```%8```!3``````````````!.
M````%@````````!*````'```````````````````````````````````````
M````'0`````````````"````````````````'0`````````````#````````
M``````/F$0``#@``````(,`@``````````@````,$@``````````(,.`````
M`````#`````7$@``````````(,.@````````"$0````I$0``%@``````(,L0
M``````````$```.,$@``````````(,/``````````$@```/Z$@``"P``````
M$#[``````````;0```!`$0#_\0``````(,`X``````````````+P$@``````
M````(,/@`````````"0```,*$@``````````(,0``````````&@```-#$@``
M````````(,0@`````````#@```!)$@``````````(,1``````````^@```!7
M$@``````````(,1@`````````.````!C$@``````````(,2``````````.``
M``0'$@``"P``````$%'@`````````!````!T$0``%@``````(,L8````````
M``@```*0$0``%@``````(,L@`````````$````!^$@``````````(,2@````
M````"Q0```"-$0``%@``````(,M@``````````@```08$@``"P``````$#@@
M`````````&````"7$@``````````(,3``````````H0```0F$@``"P``````
M$$#``````````5P```-1$@``````````(,3@``````````@```"E$0#_\0``
M````(,,```````````````,A$@``````````(,4`````````#WP```"_$0``
M%@``````(,MH``````````$```17$@``"@``````$!Q(``````````````#,
M$@``````````(,4@````````!J````#7$@``````````(,5``````````*0`
M``#D$@``````````(,5@`````````5````#R$0``%@``````(,_P````````
M``@```#Z$@``````````(,6``````````J@```,2$@``````````(,6@````
M`````'P```,:$@``````````(,7``````````"0```0R$@``"P``````$$5`
M`````````>P```$%$@``````````(,7@`````````!0```0_$@``"P``````
M$%(``````````S@```15$@``"P``````$%5``````````"@```,\$@``````
M````(,8``````````"@```+E$0``#@``````(,````````````@```.T$@``
M"P``````$!R``````````-@```-Y$@``````````(,8@`````````"0```+Q
M$@``````````(,9``````````"0```-;$@``````````(,9@`````````!0`
M``-*$@``````````(,:``````````-P```1=$@``"P``````$$=`````````
M":0```$4$@``````````(,:@````````!<P```+`$@``````````(,;`````
M`````"0```+]$@``````````(,;@`````````"0```+.$@``````````(,<`
M`````````#0```1J$@``"P``````$$(@`````````&P```+V$@``````````
M(,<@`````````(````$=$0``%@``````(,MI``````````$```-C$@``````
M````(,=``````````&````$K$@``````````(,=@`````````]````$[$0``
M%@``````(,MP``````````@```.O$`#_\0``````(,L(``````````````.B
M$@``````````(,>``````````"0```1V$@``"P``````$$*@`````````HP`
M``1[$@``"P``````$#V``````````3````)F$0``%@``````(,MX````````
M``0```2-$@``"P``````$%$``````````,0```%+$0``%@``````(,M\````
M``````$```%6$@``#```````$%8@``````````````%<$@``````````(,>@
M````````$OP```3R$@``````````(,?``````````#0```.'$@``````````
M(,?@`````````"0```,I$0``%@``````(,N```````````@```*($@``````
M````(,@``````````A0```%J$@``````````(,@@`````````"0```-T$@``
M````````(,A``````````%@```.<$@``````````(,A@`````````"0```(F
M$@``````````(,B`````````!MP```2C$0``#@``````(,`H``````````@`
M``%Z$@``````````(,B@`````````$@```.H$`#_\0``````(,L(````````
M``````*I$@``````````(,C``````````A0```&%$0#_\0``````(,L`````
M``````````.[$`#_\0``````(,_X``````````````+&$@``````````(,C@
M`````````%P```&;$0``%@``````(,N(``````````$```&F$0``%@``````
M(,N0`````````!,```(R$@``````````(,D``````````^0```*Y$@``````
M````(,D@`````````"0```2W$@``"P``````$#B``````````"0```&U$@``
M````````(,E``````````*0```+4$@``````````(,E@`````````"@```33
M$@``"P``````$!Y``````````$P```',$0``%@``````(,NH``````````@`
M``-R$@``````````(,F``````````"P```3@$@``"P``````$$"`````````
M`"0```)T$@``````````(,F@`````````"@```'2$0``%@``````(,NP````
M``````@```*B$@``````````(,G``````````"0```'=$@``````````(,G@
M`````````P````'K$0``%@``````(,NX``````````@```.`$@``````````
M(,H``````````$@```.3$@``````````(,H@`````````*````,%$@``````
M````(,I``````````"0```'X(`````````````````````````````-J$@``
M````````(,I@`````````)````(,$@``````````(,J``````````$````*P
M$@``````````(,J@`````````"0```(:$@``````````(,K``````````%``
M``(M$@``````````(,K@`````````$````/K$0``#0``````$%I(````````
M6^H`;&EB<&5R;"YS;P!097)L7V-R;V%K`%!E<FQ?<W9?,G!V7V9L86=S`%!,
M7W!E<FQ?9&5S=')U8W1?;&5V96P`7T193D%-24,`4&5R;%]A=E]S:&EF=`!0
M97)L7VUG7W-E=`!097)L7VYE=UA37V9L86=S`%!,7V-O;7!C=@!P97)L7V-O
M;G-T<G5C=`!03%]P87)S97(`4&5R;%]D;W5N=VEN9`!?4%)/0T5$55)%7TQ)
M3DM!1T5?5$%"3$5?`%!,7V1O7W5N9'5M<`!P97)L7W!A<G-E`%!E<FQ?;F5W
M4U9P=@!097)L7W-V7W-E='!V`&5N=FER;VX`4&5R;%]N97=84P!097)L7W-Y
M<U]I;FET,P!P97)L7W)U;@!03%]E>&ET7V9L86=S`&)O;W1?1'EN84QO861E
M<@!03%]C=7)S=&%C:VEN9F\`4$Q?=&%I;G1E9`!?9FEN:0!P97)L7V1E<W1R
M=6-T`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V%L;&]C`%]'3$]"04Q?3T9&4T54
M7U1!0DQ%7P!03%]I;E]E=F%L`%!,7VUE;6]R>5]W<F%P`%!E<FQ?<V%V95]D
M97-T<G5C=&]R7W@`4$Q?;W``4$Q?=&]P7V5N=@!097)L7V%V7V9E=&-H`%!,
M7V5V86Q?<F]O=`!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?9G)E90!L:6)M+G-O+C4`;&EB8W)Y
M<'0N<V\N-`!L:6)U=&EL+G-O+C<`;&EB8RYS;RXW`%]?;6)?<V)?;&EM:70`
M7U]S<&%R8U]U=')A<%]S971U<`!M96UM;W9E`%]?<W1A8VM?8VAK7V=U87)D
M`&=E='!I9`!M96UC<'D`<F5A9&QI;FL`9V5T=6ED`')M9&ER`')E861D:7(`
M;'-E96L`7U]S=&%C:U]C:&M?9F%I;`!?7W!R;V=N86UE`&QS=&%T`'-T<G-T
M<@!?7V5R<F]R`')E860`<W1R;F-M<`!S=')N8W!Y`'5N;&EN:P!R96%L;&]C
M`%]#=7)R96YT4G5N94QO8V%L90!S=')T;VL`<W1R9'5P`&UE;7-E=`!?:6YI
M=%]T;',`;W!E;F1I<@!S=')C;7``<W!R:6YT9@!A=&5X:70`86-C97-S`'-T
M<FQE;@!O<&5N`&5X96-V<`!C;&]S961I<@!M:V1I<@!C;&]S90!?961A=&$`
M7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L-2\U+C$P+C$O
M;6%C:"]#3U)%`&YA;65?;&]A9%]M>5]P87)?<&P`<&%R7VEN:71?96YV`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V5N=E]C;&5A;@!P87)?9&ER;F%M90!P87)?
M9FEN9'!R;V<`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS7VEN:70`<&%R7VUK
M=&UP9&ER`'!A<E]C;&5A;G5P`&UA:6X`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'-I>F5?;&]A9%]M>5]P87)?<&P`6%-?26YT
M97)N86QS7U!!4E]#3$5!4E-404-+`'!A<E]B87-E;F%M90!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!&0E-$<')I=F%T95\Q+C``1D)31%\Q+C``````
M``````$``````````@`!``$``@`"``(``````````0````(```````$````!
M``(``0`"`````0`````````!`````@`"``$````!``$``@`!``$``@`"``(`
M`@`!`````@`"``(``0`"`````@```````0`"``$``0`"``$````!`````@`"
M``(``@````(``@`"``$````!``(``0`!``(```````(``@`!`````@`!````
M`@`!``,````"```````"``(``@````(````"```````!```````!``(```)<
M````$``````/'OJ@`````P``!/L````0!WHHL`````(```4+````````````
M(,L0````!@```!,`````````````````(,L8````$0```!,`````````````
M````(,L@````$@```!,`````````````````(,M@````%````!,`````````
M````````(,MH````&P```!,`````````````````(,MI````-@```!,`````
M````````````(,MP````.0```!,`````````````````(,MX````/@```!,`
M````````````````(,M\````0````!,`````````````````(,N`````10``
M`!,`````````````````(,N(````4@```!,`````````````````(,N0````
M4P```!,`````````````````(,NH````6@```!,`````````````````(,NP
M````7@```!,`````````````````(,NX````80```!,`````````````````
M(,.`````!````!4`````````````````(,.@````!0```!4`````````````
M````(,/`````!P```!4`````````````````(,/@````"@```!4`````````
M````````(,0`````"P```!4`````````````````(,0@````#````!4`````
M````````````(,1`````#0```!4`````````````````(,1@````#@```!4`
M````````````````(,2`````#P```!4`````````````````(,2@````$P``
M`!4`````````````````(,3`````%@```!4`````````````````(,3@````
M&````!4`````````````````(,4`````&@```!4`````````````````(,4@
M````'0```!4`````````````````(,5`````'@```!4`````````````````
M(,5@````'P```!4`````````````````(,6`````(0```!4`````````````
M````(,6@````(@```!4`````````````````(,7`````(P```!4`````````
M````````(,7@````)0```!4`````````````````(,8`````*````!4`````
M````````````(,8@````*P```!4`````````````````(,9`````+````!4`
M````````````````(,9@````+0```!4`````````````````(,:`````+@``
M`!4`````````````````(,:@````,````!4`````````````````(,;`````
M,0```!4`````````````````(,;@````,@```!4`````````````````(,<`
M````,P```!4`````````````````(,<@````-0```!4`````````````````
M(,=`````-P```!4`````````````````(,=@````.````!4`````````````
M````(,>`````.P```!4`````````````````(,>@````0@```!4`````````
M````````(,?`````0P```!4`````````````````(,?@````1````!4`````
M````````````(,@`````1@```!4`````````````````(,@@````1P```!4`
M````````````````(,A`````2````!4`````````````````(,A@````20``
M`!4`````````````````(,B`````2@```!4`````````````````(,B@````
M3````!4`````````````````(,C`````3@```!4`````````````````(,C@
M````40```!4`````````````````(,D`````5````!4`````````````````
M(,D@````50```!4`````````````````(,E`````5P```!4`````````````
M````(,E@````6````!4`````````````````(,F`````6P```!4`````````
M````````(,F@````70```!4`````````````````(,G`````7P```!4`````
M````````````(,G@````8````!4`````````````````(,H`````8@```!4`
M````````````````(,H@````8P```!4`````````````````(,I`````9```
M`!4`````````````````(,I@````9@```!4`````````````````(,J`````
M9P```!4`````````````````(,J@````:````!4`````````````````(,K`
M````:0```!4`````````````````(,K@````:@```!4``````````)WCOT!`
M``!E`0```$``#EL!````@<?@"('H````````````````````````````````
M````````G>._0,0&(`2&!B`0D!``&:0&(`BC.*``@*"@`(,L<`,%``@SH`#`
M`01``!7@<*/PQEX@"`+`P!()``@PQG$@`,0(P`"%**`8@*"@``)```R&`.`!
MA3B@&,)9(`"`H*`O@V1``\)Q(`#$",``A2B@&("@H``23__XA@#@`0,`"#""
M$&`X`L!`#P$```!`!"L=`0```!$`!!5`!"L:D!(B('___\H!````D!``$9(0
M`!)```E<E!``$$`$*L*1.B``0`0K&`$```!`!"GF`0```!!O__(1``05`0``
M``$```"=X[]`(P`(,L(,8\"`H&``$D``#R$`"##"7"`0Q%A``"+`@`J"$"`!
M@@!@")_`@`#"="`0PEP@$,180``*^+_\@@!@"((0(`'"+&/`@<_@"`$````P
M:``#`0````$```"=X[]`@<_@"`$````P:``%`0````$````!`````0```)WC
MOT`#``@PQ%AB6`+`@`B0$&)8`P```((08``"P$`$`0```)_`0``!````@<_@
M"`$````P:``#`0````$```"=X[]`@<_@"`$````P:``%`0````$````!````
M`0```,0*``"'**`8@*#@``)```Z($``(`P`$%I`"(`'$6&(PRDB``,0*``"#
M..`8@*!`!8<HH!B)9$`(@*#@`!)/__J0`B`!@</@")`0``0P:``%`0````$`
M```!`````0```)WCNP"X!Z5O@A`___!WJ'^&!B`XB!``'(LP<""Z!Z7OPEC`
M`(4P<""""$`%PG$@"(0(@`7$<0``B`$@$("A`!T2;__XA@#@"((0/_^Z!R)H
MKS!P((H'I=?$64``PEE_V,A9?ZB"&$`"QEE_F((80`2"&$`#A3!P'X(`0`&$
M$(`!A`B`%\1Q8!B*`6`(@*%`'3)O__/$64``PE^H?Q\6H)XG&[9ZQ%^H?YX3
MX9FF%..APEA``/!?I:?"=Z.WB3!P&_98H`BP!@`/QEB@((4H<`7"7ZA_B!$`
M`L1?J'^("0`7^%A@$,)?I6_*6*`8N@\`&X8`P`'"7Z5WA@#`#X0I0!O87Z6_
MA@#`!,A?H[>*`4`!PE^E?X00@!V*`4`/M"\`!(8`P`+Z7Z6'B2[P'K@'``'"
M7Z.WMS;P`H8(P!?47Z77MA;`!+H'0`_07Z7OM@[`%[@'``_D7Z8'A`[``;(N
MP`/H7Z87A!"`&KH'0!OV7Z6/@RCP!8H!0`+$7Z.WB3#P&[8&P`_J7Z8?B!$`
M`9@#``^("0`7E`*`#X,PL`**`4`$A2BP'HH)0!>"$$`"D`(`#X((0!>D!(`/
MM`C``9HH0`6)*7`%LA9`&O1?I9^%,7`;N`<`&800@`2V!L`!R%^EEX,H\!Z$
M"(`7AS#P`K@'``*&$,`!N`\`%X8(P!>(`0`/L@E``Y8HP!R%+S`%FA-`&?)?
MI:^#-S`;N@=`#=I?I;>"$$`"B`$``X4I<!Z""$`7BS%P`KH'0`&*$4`"N@]`
M%XH)0!>T!H`/A@\`!9(I0!V%+W`%EA+``X,W<!NV!L`+UE^ESX(00`*T!H`%
MRE^EQX4O,!Z""$`7N3<P`K8&P`&X%P`"M@[`%[@/`!>R!D`/A@]`'*`O`!N%
M+O`%DA)``X,V\!N(`0`)TE^EYX(00`*P!@`<^%^EWX4O<!Z""$`7NS=P`H@!
M``&Z%T`"B`D`%[H/0!>:`T`/A@[`':(O0`2%*3`%H!0``X,Q,!NT!H`0X%^E
M_X(00`*R!D`=^E^E]X4N\!Z""$`7MS;P`K0&@`&V%L`"M`Z`%[8.P!>*`4`/
MA@D`&Y8"P`^%+K`%HA1``X,VL!NP!@`1XE^F#X(00`*X!P`/A2DP'H((0!>)
M,3`"L`8``8@1``*P#@`7B`D`%Y("0`^&#H`$N@=`#X4N,`6@!``/@S8P&YXN
MP!J>$\`#@A!``L9?IB^R!D`/@@A`%]Y?IB>%+K`>A@#`$\9WI4^R!D`!PE^F
M-YH#0!NU-K`"L@Y`%[06@`*"`$`3PG>E/[0.@!>V*0`8A@X`&I@#``2%+G`%
MMA;``X,V<!N:`T`;@A!``H@N@!F""$`7B@%`&O1?IC^:`T`!PE^F1Z($0!.%
M+C`>F@M`%X(`0!/"=Z4?J`4`$\)?ID^Q-C`"J@5`$[`6``*>`\`3L`X`%X(`
M0!/"=Z4/A@Y`&+8N``V%*W`%B!$``X,S<!N8`P`$@A!``I8"P!CP7Z97@@A`
M%[0&@!.8`P`!PE^F7[`&`!.%+G`>F`L`%[,V<`*"`$`3PG>D[\)?IF>R%D`"
MA2LP!;(.0!>"`$`3A@M`&<)WI-^#,S`;MA;``X(00`**`4`;@@A`%X@N0`R*
M`4`!PE^F=Y0"@!F%*W`>B@E`%_)?IF^;,W`"@@!`$\)WI,_"7Z9_FA-``K(&
M0!.%*7`%F@M`%X(`0!.&"P`-PG>DOX,Q<!N($0`#@A!``I8"P`2""$`7MBM`
M!98"P`'"7Z:/N`<`#84K,!Z6"L`7VE^FAYDS,`*"`$`3PG>DK\)?II>8$P`"
MF@-`$X4J\`68"P`7@@!`$X8)0`S"=Z2G@S+P&[86P`."$$`"E`*`&X((0!>(
M*P`+E`*``<)?IJ>2`D`,V%^FGX4I<!Z4"H`7BS%P`H(`0!/"=Z2?F`,`$XH1
M0`+F7Z:O`R/&[XH)0!>"$&#<A@K`!84JL`6F!,`!@S*P&X@1``."$$`"N`<`
M!,1?IK>""$`7!R/&[X80X-RX!P`!PE^FOX0`@`/$=Z27N`\`%X4J\!Z"`$`#
MPG>DCY<R\`+"7Z;'MBE`"I82P`*0`@`%E@K`%X(`0`/"=Z2'A@J`"X@JP!RV
M%L`#!R/&[X4O,`62`D`;]E^FSX,W,!N&$.#<@A!``@4CQN^""$`7A!"@W+8&
MP`*2`D`!PE^FWX4JL!ZZ!T`+UE^FUY4RL`*2"D`7E!*``H(`0`/"=Z1_E`J`
M%Y8"P`.%*G`%A@\`"H,R<!N($0`#@A!``I`"``2""$`7"2/&[Y`"``'"7Z;O
MB!$@W(4O,!Z0"@`7@@!`!,)WI'>**H`)PE^F][DW,`*@!``*N!<``M1?IN>X
M#P`7@@!`!,)WI&^&"D`<E`*`!(4J,`6*$4`#@S(P&[H'0`6"$$`"!R/&[X((
M0!>(+P`(N@=``<)?IP>&$.#<I`2`'`4CQN_X7Z;_@@!``X00H-S"=Z1GN`<`
M`L)?IP^Z#T`7A2IP'I,R<`*"`$`#PG>D7X,W<!N2$D`"A2]P!9(*0!>&"@`)
M@A!``H@1``.""$`7H`0`!`DCQN^@!``!PE^G'X@1(-R%*C`>H`P`%X(`0`3"
M=Z17BBI`'<)?IR>1,C`"H@1`"9`2``+27Z<7D`H`%X(`0`3"=Z1/A@]`"*@%
M``B%+#`%BA%``X,T,!ND!(`%RE^G+X(00`+$7Z<W!S*8L(((0!>&$.'6I`2`
M`<)?IS^$`(`$Q'>D1X4O<!ZD#(`7@@!`!,)WI#^2`D`$PE^G1[LW<`**`4`$
MNA=``KH/0!>"`$`$PG>D-X4LL`60'T`(@S2P&Y`:`!""$$`"H@1`"-!?IT^"
M"$`7J@5`'84L,!ZB!$`!PE^G5Z$T,`*B#$`7H!0``H(`0`/"=Z0OH`P`%Y`"
M``.%+'`%NAP`'8,T<!NZ'T`2@A!``J@%`!W$7Z=G@@A`%YX#P!#Z7Z=?J`4`
M`<)?IV^$`(`#Q'>D)X4LL!ZH#0`7@@!``\)WI!^Z!T`#PE^G=Z4TL`*D%(`"
M@@!``\)WI!>D#(`7PE^E3X4M,`6@'(`0H!P`$8@`0!*J!4`0X%^G?X,U,!N"
M$$`"Q%^GAZ`$``.""$`7A`"``ZH%0`'$=Z0/PE^GCX4L<!ZJ#4`7HS1P`H(`
M0`.B%$`"PG>D!\1?I3^B#$`7PE^GEZ0<0!*$`(`1Q'>E-Z0<@!2"`$`#PG>C
M_YX#P!*%+7`%Y%^GGX,U<!N"$$`"Q%^GIZ0$@`.""$`7G@/``<)?IZ^$`(`#
MQ'>C]X4M,!Z>"\`7J34P`H(`0`/"=Z/OPE^GMZ@5``*%*_`%J`T`%X(`0`.B
M'0`1PG>CYX,S\!NB'$`5@A!``H@!`!'$7Z?'@@A`%[0&@!3B7Z>_B`$``<)?
MI\^$`(`#Q'>CWX4M<!Z("0`7@@!``\)WH]>B!$`#PE^GUZLU<`*J%4`"R'>E
M9X(`0`/"=Z//J@U`%\)?I1^%*3`%J!U`%*@=``^"`$`5PG>E%X,Q,!O(7Z4W
M@A!``L1?I^>H`0`4Z'>E+X((0!?H7Z??B2OP'H0`@`/$=Z/'GS/P`L1?I2^H
M!0`#GA/`!)X+P!?(7Z5G@@"``:H;P!6""$`7PG>E5ZH=0`3&7Z57@S!P&[0&
M@!6%*/`%ARDP'H(00`+$7Z4/@@A`%X0`@`_$=Z4'M`:``84Q,`*T#H`7@S:P
M&X00@`/$=Z4GQE^E)X4NL`6"$$`"Q%^E5X@(P!?&7Z47@@A`%YX9``^P!@`$
MGAO``H0`P`_>7Z57@@"``8<K\!ZJ"$`7A3/P`H,U<!N&$(`#A2UP!9X(P!?&
M7Z4'B!O`!((00`*$&0`:@@A`%\1WI/>$`,`"R%^D[X<NL!Z"`(`!@@A`%\)W
MI5^(`0`/M3:P`LAWI.>#,'`;M!:``\9?I5^T#H`7R%^DWX4H\`6&'H`/WE^E
M7X(00`*$&,`5@@A`%[`&``*'+7`>L`8``84U<`*P#@`7B`$`&H80@`/(=Z37
MA2XP!8@(P!>#-C`;M!D`&H(00`+$7Z3GM!Z`#X<K\!Z""$`7M`"`&K(&0`2%
M,_`"@@:``880@`.J"$`7A2UP!9X(P!>#-7`;AAO`!,A?I,^"$$`"A!C`&,9?
MI->""$`7B`$`#\AWI,>$`,`"ARXP'H(`@`&Q-C`"M`A`%X4NL`6P%@`#@S:P
M&[`.`!>&'@`/@A!``MY?I+^$&,`5@@A`%[(&0`*>`\`8WG>DMX4U<`*R!D`!
MARUP'K(.0!>#-G`;AA"``X4N<`6(",`7L!D`&((00`+$7Z3'L!X`&H((0!>P
M`(`8F@-`!(4VL`*"!@`!ARZP'IX(0!>#,_`;AA"``X4K\`6T",`7AAZ`!((0
M0`+(7Z2OA!C`&<9?I+>""$`7J@$`&H0`P`*'+G`>@@"``;,V<`*P"$`7A2XP
M!;(60`.#-C`;L@Y`%X8>0!J"$$`"A!C`#X((0!>'*_`>F@-``L1?I*>:`T`!
MM`"`&9H+0!>%,_`"@S-P&X80@`.%*W`%B`C`%[(9`!F"$$`"LAY`&(((0!>$
M!4`9F`,`!(<N,!Z"`(`!A38P`IX(0!>#,_`;AA"``X4K\`6P",`7AAX`!((0
M0`*$&,`-QE^DGX((0!>$!H`"M`#`&((`@`&'*W`>B`A`%YLS<`*%*3`%FA-`
M`X,Q,!N:"T`7AAM`&((00`*$&,`/@@A`%Y@#``*F!,`-A3/P`I@#``&'*_`>
MF`L`%]Y?I(^#,S`;AA"``X4K,`6&",`7FAC`#8(00`*:&T`$@@A`%X4I,!ZR
M!H`-B3$P`H(&0`&$$0`"R%^DE[0(0!>R"(`7@A9``[`!``.""P`!A@Y``X(0
M0`.:`\`9ARZP!:8$P`&)*S`>A3:P&YDS,`*$$(`#F!,`!(0(@!>8"P`7I@3`
M`L1?I(>"$P`9I@S`%X8+`!F"#H`!J@"`#((00`.%-/`;L@8``8<L\`6)+K`>
MA!"``X,VL`*$"(`7AA!`!((&0`*R",`7G@A`%X(60`R8#D`,AROP!8(,P`&%
M,_`;@A!`#(DL\!Z$$(`#IS3P`H(#0`&$"(`7IA3`!*8,P!>"`$`"F@A`%X(4
MP!F&#,`9@@O``8(00`.V!L`9ARMP!9@%0`&%,W`;E@+`$XDK\!Z$$(`#@S/P
M`H0(@!?>7Z1OAA!`!((#``*8",`7L@A`%\9?I'^)*W`>@A,`$X(+0`&F"P`3
M@A!`$[0`P`R%-G`;M@;``8,S<`*'+G`%@A!`!)H(0!>$$(`#@A-`#(0(@!>&
M"T`,M@;``H(.0`&V#L`7@A!``Y0"@`V'+O`%E@+``8DN<!Z%-O`;@S9P`H00
M@`."$$`$A`B`%\A?I'>8"$`7E@+``H(3``V6"L`7A@L`#8(.P`&%,O`;@A!`
M`X<J\`6R`0`,A!"``X(&@`&)+O`>A`B`%[<V\`*"`$`"MA;`!)H(0!>)*O`>
MM@[`%X(6P`R&#L`,@@K``;0#P!O>7Z17A3-P&X(00`.7,O`"E`*``8<K<`66
M$L`$A!"``Y8*P!>$"(`7@A+`&Y0"@`*V"L`;E`J`%X(+0`&"$$`;N`<`"X<J
ML`6P!D`!A3*P&XDK<!Z$$(`#@S-P`H0(@!>&$$`$@@8``L1?I&>:",`7L`A`
M%X(30`NV`(`-E@M`"X(*@`&'+C`%@A!`"X4V,!N"!H`!B2JP'H00@`.5,K`"
MA`B`%Y02@`2"`$`"R%^D7Y0*@!>8"$`7@A*`#88*@`V"#@`!M`$`"H4S,!N"
M$$`#B2XP'K@'``&'*S`%@S8P`H00@`."$$`$A`B`%YH(0!>X!P`"@A-`"K@/
M`!>4"T`*@@L``8(00`J2`D`-AR\P!:8&P`&%-S`;B2LP'H00@`.#,S`"A`B`
M%X800`2"!,`"F`C`%Z8(0!>"$P`-A@L`#8(/``&V`\`,WE^D/X4T\!N"$$`#
MARSP!8(&@`&)+S`>A!"``[DW,`*$"(`7N!<`!((`0`+$7Z1/N`\`%Y0(0!>"
M%P`,A@\`#((,P`&T`(`<B2SP'H(00`.%,K`;D@)``8<JL`6#-/`"A!"``X(0
M0`2$"(`7F`A`%Y("0`*"$P`<D@I`%[@+`!R""H`!@A!`'(H!0`R'*G`%E@;`
M`84R<!N)*K`>A!"``X,RL`*$"(`7AA!`!(("P`+(7Z1'E`C`%Y8(0!>"$H`,
MA@J`#((*0`&X`0`*A3+P&X(00`.'*O`%@@:``8DJ<!Z$$(`#DS)P`H0(@!>2
M$D`$@@!``I(*0!>8"$`7@A)`"H8*0`J""L`!M@/`"=Y?I">%,S`;@A!``XDJ
M\!Z*`4`!ARLP!8,R\`*$$(`#@A!`!(0(@!>4"$`7B@%``L1?I#>"$H`)B@E`
M%Y(*@`F""P`!M`"`"H(00`F'*7`%I@<``84Q<!N)*S`>A!"``X,S,`*$"(`7
MAA!`!(($P`*8",`7I@A`%X(3``J&"P`*@@E``9`"``R%-/`;@A!``X<L\`6"
M!L`!B2EP'H00@`.+,7`"A`B`%XH10`2"`$`"R%^D+XH)0!>2"$`7@A%`#(8)
M0`R"#,`!N`$`!84R<!N"$$`#ARIP!8(&@`&)+/`>A!"``X<T\`*$"(`7@@!`
M`H00P`28"$`7B`B`%XH9``6Z!T`$A2LP!8H90`F#,S`;D`(`!8<J<!Z"$$`"
MA3)P`H((0!>0`@`!@A"``Y((0!>0"@`7A!I`!+8#P`G>7Z0'@S(P&X88@`R%
M*C`%B`<``X<K,!Z"$$`"A3,P`H((0!>"`0`!A!"``XH(0!>("(`7PE^D'X09
M``FX`$`$AAB`"(,Q<!NZ!T`#A2EP!8<J,!Z"$$`"D3(P`H((0!>0$@`#N@=`
M`<9?I!>0"@`7N@]`%X0:``2T`,`(@S=P&X88@`6%+W`%B`;``X<I<!Z"$$`"
MA3%P`H((0!>"`0`!A!"``XH(0!>("(`7D!D`"*`$``2%*7`%D!H`'8,Q<!N2
M!P`(AR]P'H(00`*[-W`"@@A`%[H70`."`D`!N@]`%Y((0!>#,G`;A!]`!,A?
MI`^&&(`%A2IP!;@!`!V"$$`"B`:``X4Q<`*""$`7AREP'H(!``&$$(`#B@A`
M%X,Q<!N("(`7NAD`';8#P`3>7Z/GA2EP!;H?0`F"$$`"H`0`'8<J<!Z""$`7
MA3)P`J`$``&"$(`#H`P`%Y((0!?"7Z/_A!I`!+H`0`F&&(`%@S0P&X@'``.%
M+#`%AREP'H(00`*%,7`"@@A`%X00@`."`0`!B`B`%XH(0!>$&0`)I`2`!(,Q
M<!N&&(`0A2EP!9(&P`.'+#`>@A!``J$T,`*""$`7H!0``X("0`'&7Z/WH`P`
M%Y((0!>$'``$N`#`$(,R<!N&&(`%A2IP!8@'0`.'*7`>@A!``H4Q<`*""$`7
M@@$``800@`/(7Z/OD`A`%XH(@!>@&4`0N@$`!84J,`6@'``)@S(P&Z0$@!"'
M*G`>@A!``H4R<`*""$`7I`2``8(0@`.("$`7I`R`%X09``6V`\`$WE^CQX,T
ML!N&&(`(A2RP!8H'``.'*C`>@A!``H4R,`*""$`7A!"``X(!0`&*"(`7D`A`
M%X090`2B!$`%@S(P&X88@!*%*C`%B`=``X<LL!Z"$$`"I32P`H((0!>"`0`!
MI!2``X@(0!>D#(`7PE^CWX0<@`6Z`$`2AAB`"(,Q,!N*!L`#A2DP!8<J,!Z"
M$$`"A3(P`H((0!>$$(`#@@%``8H(@!?$7Z/7D`A`%X,R,!ND&4`2N`"`!:0<
M@`2%*C`%H@1`$H<I,!Z"$$`"A3$P`H((0!>B!$`!@A"``\9?H\^("$`7H@Q`
M%X09``6V`,`$@S1P&X88@`B%+'`%B@=``X<J,!Z"$$`"A3(P`H((0!>$$(`#
M@@%``8H(@!>0"$`7A!E`!*@%``6#,C`;AAB`$84J,`6(!P`#ARQP'H(00`*C
M-'`"@@A`%Z(40`."`0`!H@Q`%X@(0!>$'$`%N@/`$8,Q,!N&&(`(A2DP!8H&
MP`.'*C`>@A!``H4R,`*""$`7A!"``X(!0`&*"$`7D`B`%X,Q<!NB&@`1A2EP
M!:(<0`2"$$`"J`4`$84I,!Z""$`7AS$P`J@%``'(7Z.W@A#``J@-`!>'+3`%
MD@A`%X4U,!N"&D`(@AA`!800@`.>!T`!A`B`%X,I<!Z>`\`"AS%P`IX+P!>$
M`\`$WE^H?X80P`&""(`7B@C`%\)SP`#"6^`(Q%O@$,9;X!BH!0`!R%O@(((!
M0`*H#0`7A`)``X((0!?H<^`(A@(`!,)SX!"$"(`7@@C`%\1SX!C"<^`@@<_@
M"`$````P:``$`0````$````!````G>._0`K&``0#``@S@<_@")`0(`#F6&/P
M`OS__0$```#"3@``A!A@/8"@``&&0"``@*```H)`(`"`B,`!`D``#I00(`"(
M$``8B`$@`<))``"$&&`]@*```89`(`"`H``"@D`@`("(P`$R3__YB`$@`90A
M`!C@7,```O0_Y:4ZH``0:``&HA``$Z($8`C@7$```O0_WP$```"0$``0DA``
M&$`$(RB4$``2*OH_^:($8`C"3(`0@*!@/1)/__20!(`0@B1`$X,X<`/")D``
M@<?@")'J(`$P:``#`0````$```"=X[\PH`>GZY`0`!B2$``0?___Q",`"#,"
MP@`.PD>GZ\1<8_"#*'`#A`!``H0`H`C"6(``"OA__L)PO_B0$``8?___N)(0
M`!`*^C_VPD>GZX'/X`@!`````0````$```"=X[\PD!``&'___ZZ2!Z?K@<?@
M")'H``@!`````0```)WCOT`Q``@PP@8@&("@?_\"0``$$0`$%8'/X`C00B`8
M?___\)`2(H@"P@`'@A`@`,)*``"`H&``$D@`!H(88#""$"``PB8@&('/X`C0
M0B`8@*```8)`(``0;__\PB8@&)WCOT`Q``0.D!`__[(0(`!`!",,L!8@P!"$
M)"J!Z````0```#!H``<!`````0````$````!`````0````$```"=X[]`(P`(
M,@,`"#+$7&-P$0`$%9(0(`#&"&.(D!(C`,)8H`@%``@RQBA@(,98HZC(7&-P
MPEC@(,I9(`B#,'`WPC%@(L1<8W!`!",.X%B@"-!T("@#``@RBA`@`,A<8W#&
M6&.X`P`(,L19(`C&<*`PQ%QC<,)88V`"P$`#Q%B@",I88*C*<*`XPEQC<,18
M8`C`<*!`PEQC<,188`@#``@RP'"@2,A<8W#&6&.PQ%D@",9PH%"!S^`(`0``
M``$```"=X[[``L8`20$```#"3@``@*!@`!)```0!````@<_@"`$```!`!",O
MD!``&`+R/_RD$``(`P`$%04`!!6F$&*8`P`$%:@0HJ"L$&*HJ@>G=R\``#P[
M```00`0CPI`0`!*2$``3`L(`*Z("(`A`!"-5D!``$0+Z/_F2$``40`0C49`0
M`!$"^C_U`0```$`$(_V0$``8H!``"$`$(_J0$``1D`(`$)`"(`)`!".6D3H@
M`)(0`!:4$``8EA``$4`$)`F@$``(D!``$$`$(OZ2$``5@*(__P)```;"%Z=_
M@@A`%X"@0!T"0``3`0```$`$(M60$``00`0CHY`0`!!`!".9D!``$I(0`!,*
M^C_9H@(@"$`$(^20$``20`0C"I`0`!B!S^`(`0```('/X`@!````?___M)`0
M`!`0;__O`0```)WCOL"2!Z=W0`0B1I`0`!B`HB``$D``#\87IW\#```\!0``
M$(8(P`$#```HA!C``H88P`&`H``"B&`__X"@``."8#__@)$``1)```60$``8
ML!`@`('/X`B1.B``0`0BP9(0(`*`H``(L&`__X'/X`B1.B``,&@``P$````!
M````G>._,,).0`""&&`]@*```81@/_^R!D`"0`0CJI`0`!FF$``(D@>GZW__
M_M:0$``8`L(`5J`0``A`!".B*0`(,X,TX`"`H@`!.F@`0<(.0`#"3@``$&@`
M`X@0`!C"20``A!A@/8"@``&&0"``@*```H)`(`"`B,`!,D__^8@!(`&0!.`"
MX`>GZY`B`!CB72/PH2PP`Y`"``1`!",JD3(@``+"`&/0=``1Q`>GZP,`"#/(
M6&/PQ@X``(4HL`/(60`"@RC@&(,X8!B`H&```D``$L8I``"`H&`]`D``$((0
M(#T0:``%A@8@`8"@8#T"0``+@A`@/<0(P`"(`2`!A@#@`8,HH!B#.&`8@*!@
M`!)/__?$*0``@A`@/80!(`'"*0``P@Y``+(&8`'"*(``@RA@&("@8``23__[
MA`"@`;`0(`"!S^`(D3H@`,(.0`"R!F`!PBP``(,H8!B`H&```D?_^*`$(`'"
M#D``L@9@`<(L``"#*&`8@*!@`!)/__2@!"`!$&__\+`0(``I``@SHA`@`-!=
M(_#"6@```L!`"I(0(!"$$``(A`"@",)8@``*^'_^H@1@`8($8`*#.&``DRAP
M`P4`"#+"`*/(@*!@`!)(`!*"$"`!D!``"4`$(MK"(*/(`L(`$Z00``B#/&``
MTETC\*$H<`-`!"*SE!``$.1U(_#"72/P@@0``<!P8`@0;_^1XB>GZT`$(>L!
M````@SQ@`-!U(_`*^C_WH2AP`[`0/_^!S^`(D3H@``$````!````G>._$`,`
M!!4'``05@A!BP,)WI\<%``05`P`$%<A(XK"$$*+(@A!BT,)WI]>&$.*P`P`$
M%<1WI\^D$``#@A!BV,)WI]^`H2```P`$%<9WI[^"$&,``D``-<)WI^<#``06
M!0`$%>A88CBJ$*+P$&@`":8'I\=___]3D!``$N1<P`#"3(``@*!@``)``"BF
M!.`(?__^?)`0`!*B$``(`O(_]I(0`!C"2@``@*!@``)/__(!````0`0B.Y(0
M`!@J^C_QY%S``$`$(N^0$``8H!``"$`$(NR0$``4H`0`"$`$(NF0$``1H`0@
M`4`$(H:0!``(DA``%900`!B6$``4F!``$4`$(OB@$``(D!``$G___RV2$``0
MY%S``,),@`"`H&``$D__W*8$X`B!S^`(`0```#!H``0!`````0````$```"=
MX[\0`P`(,A,`!!:H$&,@DA)B")00("*0!Z?%PET``,)WI^>"$"``0`0B=B<`
M!!41``05D!(B^'___BHE``05$0`$%2,`!!60$B,(?__^)2$`!!41``05?__^
M(I`2(Q`1``05?__^'Y`2(R!___X=D!3C*!$`!!5___X:D!(C.'___AB0%*-(
M?__^%I`48HA___X4D!0C6!$`!!5___X1D!(C:!$`!!5___X.D!(C>!$`!!5_
M__X+D!(CB!$`!!5___X(D!(CF!$`!!5___X=D!(CJ`+"``22$``(?__^Z9`4
M(U@1``05?__^%I`2(\`BP@`'$0`$%9(0``@1``05?__^X)`2(]@1``05?__^
M#9`2(^@"P@`0DA``"'___MF0%*-($P`$%I`4XRA___[5DA)@(,)?I^?$70``
M@AA``H00(``*P$`9`0```('/X`@!````$0`$%7___?J0$B/X`L(`!I(0``A_
M__[&D!1BB!!O_^X3``06$P`$%I`'I]:2$F`00`0@[Y00(`HJ^C_G$P`$%I`4
M8HA___ZZD@>GX!!O_^(3``060`0B/@$````!````,&@``P$````!````G>._
M0$`$(B>P$"``0`0AS9$R(``JR@`"\%H``('/X`@!````,&@`!P$````!````
M`0````$````!`````0```)WCOT`BQ@`(,0`$%<(.``"A*&`8@*0@`!)```4!
M````,0`$%1"$(,^1[B*80`0B19`0`!B0`@`8E`(__X"F``H:8``5"P`$%L)9
M8C#0"C__Q`A``)$J(!B)**`8@*$`"!)``"B#.B`8$&@`!X80``&#*&`8A3A@
M&("@@`,20``AD!```90"O_^`I@`**F__^<(*@`"`HH`8$F``"L998C#P66(P
MA3P@&,).``"`H(`!(D?_W3$`!!40A""J@>@``)0"O_^`I@`*.F``")0B@!C$
M2H``PDC``("@@`$B3__ZE`*__Y0B@!B"`J`"@*!D``A@`!2@$"``@<?@")'H
M`!`0:``#A3D@&)$J(!B#.B`8@*"``0)'_^&`HH`8E`*__X"F``HJ;__YT`J`
M`("B@!@B;__=\%EB,!!O_^+&66(P(0`(,I(0`!B0%"/00`0@Y90"H`$0;__I
MH!0CT`$```"=X[]`?___IY`0`!A___<%`0```'___7NB$``(@*(@``)```@!
M`````L8`!@$```#"3@``@*!@`!)```03``06@<_@"`$```"0$``10`0A+9(2
M8"B`I$`($F__^@$```!___W`@>@```$````P:``%`0````$````!`````0``
M`)WCOS"0!ZA_D@>HA_)WJ(>4!ZB/]'>HCT`$(,KP)ZA_`P`(,L1(8VB`H*``
M`D``80<`"#+"!ZA_Q`CC:8(`8`61.&``A!"@`P;"`&O$*.-IT'>GYX(0``#1
M'Z?GPG>G[X(0(0^5H!$(T1^G[X,H<#;"=Z?OD:*(2-4?I^^!J@K*+4@`<!$`
M!!9`!"'FD2HP`\I?J(<#``@SAA`@!-!P8^@#``@SEA``",190`":`C_XU`>H
M?\1R```%``06QB!CX`,`!!:$$*)(@A!@.,)R(`B`HJ`!`P`$%L1R(!""$&!`
M!$``"\)R(!B($"`!AA`@",190`."`L`#B`$@`88`X`B`HH`$%$__^\1P8!B"
M`J`$-0`(,X,X8`#07J/0E`*@`X,H<`,3``05DA)A@)@0(`#`<T`!0`0@4Y4Z
MH`"PDB```D``1`$```!`!"#NT%ZCT!$`!!5___T#D!(C.`+"``DS``@ST%ZC
MT$`$(;:Q/B``0`0AG`$```"!S^`(`0```-!>8]@BP@`W$0`$%7___WT!````
MT%ZCT$`$(:JQ/B``0`0AD`$```"!S^`(`0```$`$(10!`````P`(,P+"`#'0
M<&/00`0@#P$````#``@R!P`(,L`H8Q#"!ZA_Q`CC:8(`8`61.&``A!"@`P[Z
M/YG$*.-I@S(P`80*(`&"$$`"PG>GY]4?I^>"$```PG>G[X(0(0^1H!$*@RAP
M-I6B"$C1'Z?OPG>G[Y&BB$C5'Z?O@:H*RAU/_Y4!````$0`$%A,`"#*0$B`P
M0`0?II(28Y!`!"!LT%ZCT!!O_[RP$``(?__\P)`2(T@"\C^_T'9CV'___T0!
M````$&__R-!>H]!`!"#(D!`@`0$````P:``%`0````$````!`````0```)WC
MNL`#``@R$0`$%;H08R"0$B-(PE]``,)WI^>"$"``?__\J`$````#``06HA``
M".!88C"0$``80`0@:I(0`!`"P@`.`0```!$`!!62$``8?__];)`2(WC"7Z?G
MQ%]``((80`*$$"``"L!`7@$```"!S^`(`0```$`$(1*0$``8`P`$%J00``CF
M6&(XD!``&4`$(`R2$``3`O(_[+(0``@#``05J`2@`:H08I@#``05K!!B\*0'
MH^>N!Z-O.0``/#<``"#"3D``@*!@``+$0`>S9$`5D!``$4`$($J2$``9`L(`
M+0$```!`!"#VD!``&8,Z(`#(3```B@(__X<Y8`""!D`!Q$A__X"@@`0"2``%
MA@#`&1!H``V"!0`(B@(__\`HP`"0$``%P@C__\1,``"#*&`8@SA@&("@0`("
M3__XA@#__X(%``B`H&/_%$?_OY00`!F6$``0F!``&)(0`!9`!"#PD!``$I`0
M`!)`!!_EDA``%X"B(``20``&PA>C=X((0!R`H$`;`D``"9`0`!*0$"``0`0?
MRY(0`!,*^C_*LA``"!!O_ZH1``050`0?S9(0(`&`HB``,D__]Y`0(``1``05
MDA``$G___0Z0$B-X0`0?1)`0`!(0;_^@L!``"$`$()`!`````0```#!H``4!
M`````0````$````!`````P``(((8?@"=XX`!`P`(,@4``"""$&,@F!B_(,A8
M0`#(=Z?GB!`@`(88OP""!Z?_N@>G[X08OM"*!T`#F@!``Y8`0`*&`$`,`P`$
M%8@'0`*0$&-(`P`$%H(08$C"<W_P!0`$%@,`!!6$$*!0Q'%@"((08]C"<O_P
M!0`$%0,`!!:$$**8Q'%@$((08&#"<2`(!0`$%@,`!!:$$*"`Q'#_\((08&C"
M<2`0E`=`#`,`!!8S``05@A!@>`4`!!;"<2`@`P`$%JH68P#J<6`8A!"@<((0
M8(C$<2`8ZG$@**X0`!C"<J`(?__[]^IRH!`"P@`&H!``",)*``"`H&``$D``
M[`$```!___X/H!`@``,``""H$``(@AA_(`+"`*FB!T`!P@T``(,H8!B`H&``
M(D``'0,``""($``4"P`(,AL`"#*%.&`8@*"@``9```W"`6-X@*"``19(``N"
M$"!?@SB@`,9;8X"#*'`#@@!``\188$"`B*4`,F@`!8@!(`&"$"!?PBD``(@!
M(`'""0``@RA@&("@8``23__LA3A@&`,``""F$"``@AA^T*(0(`"D!T`!T%Q`
M$L)*``"`H&```D``P@,``"!___N_`0````+"``>@$``(?__\:P$```"`HB``
M$D``AY`0`!`"_/_RH@1@"$`$(#20$``3HA``"$`$(#&0$``4H`(`$:`$)`2A
M/"``0`0?S)`0`!"P$``(0`0?R9`0`!`#``06$P`$%OA88C`9``06DA)@H)00
M`!.8$R`HFA``%)80`!Q`!"`VK!``")`0`!9`!!^SDA`A[1$`!!5___N8D!(B
MT"+"`&WB7<``0`0>G.!=P`"2$``(?__^X9`0`!`"P@!EHA``"$`$(`V0$``1
M@*(@`Q1``&:@$``(?__[D`$```"`HB``$D@`"1,`!!:0$``10`0?>I(0(`"`
MHB``,D``F*\Z(``3``06$0`$%9(28"!___Q*D!(BB$`$'^B@$"``$P`$%IH6
M8P"9.B``DA)@V)`0`!B4$``60`0@")80`!P#``06$&@`$J(08.A`!!\C`0``
M`,("``"`H&`1$D``$@$```!`!!_5H`0@`>ISJ*^2$``1F3H@`)00`!:0$``8
MEA``'$`$'_6;/"``D!``&$`$'W*2$"'M@*(__P)/_^P!````0`0?E9`0`!8)
M``05DA``&'___"&0$2-(?__\KY`0`!@%``@RA!"C(,)?I^?$6(``@AA``H00
M(``*P$%]`0```('/X`@!````"O4_6Z`$(`C07``1PDH``("@8``"0`%2`P`$
M%G__^SP!`````O(_]P$```!`!!Y`H`0@"*@0``@B_3_UT%P`$1!O_TS"#0``
M0`0>.:($8`BF$``((OS_:]!<0!(0;_]X`0```.)=P`!`!!^ID!``$8"B(`,$
M3_^>H!``")$Z(``3``06D`(`$9(28+!`!![PD`(__`KZ/Y:`I"`$`D``"8($
M/_S&3P``@SA@`(($0`'$2'__@*"``Q)/_XT!````X%W@"`+T/XH!````0`0?
MD)`0`!"`HB`#"&__A9`$``@3``06D`(__$`$'MF2$F"X$&__?Z-Z!!!___QE
M`0```$`$'@N0$``0$&__M+`0``BB$"``@AA_`*0'0`'@7$`2PDP``("@8``"
M1_]%`0```'__^Z>0$``0@*(@`#)```:0$``0`OS_]J($8`@0;_\\`0```$`$
M'?:B!&`(IA``""+\__#@7$`2$&__-0$````A```@DA`_[I00(`*@'#\X0`0>
MHY`0`!>B!T`0D!``%Y00(`9`!!]NDA``$80'I_^"`(`0Q`A_\("@H``20``'
MD!``%\(,8`&`H&!#(D``ZL(,8`*0$``7DA`@`)00(`!`!!Z/-0``(,!WIT^$
M'K\X`QG12,!WIU>H!T`"@A!C`<)WIR<%._-J`R8NM\`GIY^$$*.)@A!@_L1W
MIR^$$#__PG>G-P,$#)6W,+`@!3#TN((08':$$*'PPG>G/Z8'IR>Z!Z=?Q'>G
M1Y`0`!>2$``40`0?0Y00`!JBDB``!$``*\1?IT^'/&``@RCP`X(`0`*("$`;
M@*"`!`AH`)3$7Z=7@S#P':`0`!30!Z>?I!``'80`H`'$=Z=7@@"``<AWIT^`
MHB```D@`"\)WIU<0:`"1@A`@0)00($"0$``20`0>R*($?\"0$``3?__T/:`$
M($"`I&`_%$__^)(0`!"5/&``0`0>OY`0`!+B)Z>?D!``%Y(0`!1`!!\:E!``
M&J*2(``43__9Q%^G3T`$'F60$``7Y%^G3^A?IU>#-+`#@@A@/X4X8`"&`&`!
MA`3``H(0/X"`H.`X!$@`A,(HH#B1..``E!`@0)0B@`.0`@`3E3J@`)(0(`!`
M!!X2D`(@.'__]!B0$``3P'>G7\!WIV?`=Z=OP'>G=\!WIW_`=Z>'P'>GCX,U
M,!C"+Z>7D!``$X,TL!C"+Z>;J@>GJH4U,!#$+Z>8HA``%84TL!#D+Z>>H!`@
M`(,TL`C$+Z><I@>GTX<U,`C"+Z>=QB^GF7__\_WH+Z>:Q%^G)P,`!!;&7Z<O
MI!!@T,I?IS>7,+`8VE^G/X,PL!#87Z='B3"P")4P\!C6+Z?3PB^GU)<P\!"#
M,/`(R"^GU<0OI]:),7`8A3%P$-0OI]?6+Z?8E3%P",(OI]F3,W`8QB^GVI<S
M<!#(+Z?;AS-P",0OI]R),S`8A3,P$-0OI]V#,S`(RB^GWM(OI]_6+Z?@QB^G
MX=HOI^+(+Z?CQ"^GY,(OI^78+Z?FU`P`$Y`0`!&2$``2H`0@`4`$'KVB!&`"
M@*0@%#)O__K4#``3$P`$%I80`!S`+Z?2DA)@P)@0`!6:%F,`D!``&$`$'K&4
M$``6$&_^P@$```"#,/`=H!``%-`'IY^D$``=@@"``<AWIT^`HB```D__>\)W
MIU>"$"!`DA``%((@0`B@$``!@*1``:%D@!&1.B``JSP@`)`'0`A`!!XSE!``
M%<('IY^"!``!@*!@0!)/_TG")Z>?D!``$Z(D0!!___.BH`5`%!!O_V:`I&`_
MD3C@`)00(#B4(H`#D`(`$Y(0(`"0`B`X0`0=D)4ZH``0;_^(@S4P&!!O_B.H
M$&"8@*!@01)/_QB0$``7P@Q@`X"@8$,23_\5DA`@`,(,8`2`H&!($D__$I00
M(`#"#&`%@*!@11)/_PX!````E!`@`D`$'9J2$#_&DA``$9`0`!=`!!YFE!`@
M*1,`!!:0$``8DA)@P)80`!R8$``1FA9C`$`$'F:4$``6$&_^=P$```!`!!XB
M`0````$````P:``'`0````$````!`````0````$````!````G>.W,`,`"#*@
M!Z/FHA!C(,)<0`#"=Z?G@A`@`$`$'BD!````$P`$%A<`!!:5.B``DA)A`)82
MX1!`!!Y*D!``$("B(``60``+I`>_Y;`0(`#"7Z?GQ%Q``((80`*$$"``"L!`
M%@$```"!S^`(`0```)`0`!"2$``20`0>2I00)`"@DB``!D__\[`0(`"0!"`!
M0`0=O)$Z(``"\C_ML!``"*$\(`"2$``20`0=QI00`!`0;__HP"P`&$`$'>H!
M`````0```#!H``<!`````0````$````!`````0````$```""$\``$&__QP$`
M```!````,&@`!`$````!`````0```)WCOT`1``05+0`(,H(0(`&0$B,H?__Y
M>\(MHWP"P@`&`0```,)*``"`H&`Q(D``<,)*(`%___LC`0```!$`!!:2$"`!
MD!(A&$`$'7:4$"`+`L(`+J00(``G``@SQ%H@$,($X^"`H&`!!$``(^A8H"BB
M$"`($&@`#2L`"#/26B`00`0=,)`0`!`*P@`<Q`3CX*0$H`'$!./@@@2@`8"@
M@`$$0``6H@1@")`0`!24$"``0`0=S),\H``"P@`/PEUCZ-!:``#$`B`,@(BD
M`!)O_^S@6$`1DA`@`$`$'#*4$"`"DA``"$`$'1>0$``0(OH_ZJ0$H`'$!./@
M@@"__X"@0!("0`!`@*"@`1$`!!:2$"`!D!(A($`$'4.4$"`%`L(`#J`0``C"
M6B`0$P`$%I(282A`!!R,T%A``,)<(!#06$```P`0`,0"(`R`B(`!$D``.`$`
M```1``06DA`@`9`2(3!`!!TPE!`@!0+"``JB$``($0`$%7__^2.0$B-X`L(`
M,)(0``C"7&`00`0<=M!80``1``05`P`(,L`MHWR0$B-((0`(,W__^1?`<&,8
M`L(`/]!T(]A`!!TKDA`A[8(:(!&`H``(AD`@`("@``&$0"``@(C``@)```2`
MHC__$D``))<Z(`"!S^`(`0```("@8``"3_^4$0`$%A!O_X\!````!$?_PJ`0
M(`&0$``40`0<#:`$(`'"!./@@*!`$#1/__R0$``4$&__NA$`!!9`!!P-`0``
M`!!O_\D1``06?___:0$````"P@`1H!``",)<8!"2$``(0`0<0]!80`!`!!TI
MD!``$!!O_\P1``05`P`(,]1<(]C$6&/H$0`$%I`2(6A`!!O`TEB```4`"#/"
M7&`0QEBCZ-!80`!`!!PRTEC``!!O_[T1``05)P`(,W___*707./HT'0CV,)<
M8!#06$``Q`(@#("(I``"8``3DA`@`-!:(!!`!!N[TESCZ,)<8!"D$``(Q%SC
MZ-!80`#"`B`,@(AD``)@``S@6(``U%H@$!$`!!:2$``0ESR@`$`$&YV0$B$X
M0`0;HY00(`(0;__N`0```)00(`)`!!N>DA`@`!!O__24$``(`0````$````1
M``06$P`(,14`!!:0$B&XDA)C8)02H=B"$\``$(0<"0$````!````,&@`!@$`
M```!`````0````$````!````G>._0#4`!!4Q``06M!:C`#,`!!2P%B'HLA9B
M`+80`!I____HN!`@`!"$&[:!Z````0```#!H``,!`````0```)WCOT`#``@P
M@A!B0,18?_B`H+__`F``"*``?_B?P(``H`0_^,1<``"`H+__$F___`$```"!
MS^`(`0````$```"=X[]`@<_@"`$````P:``%`0````$````!`````0```)WC
MOT!___'/`0```(''X`B!Z````````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]S
M<&%R8S8T+V-R=&DN4RQV(#$N,2`R,#`Q+S$P+S(X(#`P.C(P.C,T(&]B<FEE
M;B!%>'`@)```````4$%27T-,14%.`````````"X`````````+BX````````E
M<R\E<P```$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42```
M``!$64Q$7TQ)0E)!4EE?4$%42``````````E<R5S)7,``%!%4DPU3$E"````
M``````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1```````4$%27U1%35```````````%!!4E]$
M14)51P````````!005)?0T%#2$4`````````4$%27U!23T=.04U%`````%!!
M4E]!4D=#``````````!005)?05)'5E\P````````4$%27T=,3T)!3%]$14)5
M1P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@``
M`````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!0
M05)?0TQ%04X]````````,0````````!P87(M`````"5S````````+64`````
M```M+0```````$,Z7%1%35``+W9A<B]T;7`O`````````%1-4$1)4@``5$5-
M4$1)4@!414U0`````%1-4```````55-%4@````!54T523D%-10``````````
M4UE35$5-```E<R5S)7,E<P``````````<&%R;``````N<&%R`````"5S)7-C
M86-H92TE<R5S```E,#)X`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE
M=2TE=25S```````````O<')O8R\E:2\E<P``````9FEL90````!!4D=6````
M`!@`````````<&5R;``````P`````````"5S.B!E>&5C=71I;VX@;V8@)7,@
M9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O
M<G1I;F<@=VET:"`E:2X*````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M``````!P97)L>'-I+F,`````````26YT97)N86QS.CI005(Z.D)/3U0`````
M.@````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M```````````06%@``````!!:`'!A<BYP;```(R$O=7-R+V)I;B]P97)L"F5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E
M(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N
M>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*
M(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&
M:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V
M92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE
M<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@
M("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P
M96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R
M960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A
M<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C
M('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@
M=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H
M:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL
M;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*
M"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@
M("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@
M(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@
M("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M
M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B
M<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@
M("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@
M("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*
M"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P
M?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%
M3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D[
M"B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@
M*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!
M4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@
M)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@
M36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@
M;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@
M(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@
M9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E
M*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C
M=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER
M95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F
M.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N
M+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I
M;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L
M9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL
M96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@
M("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@
M("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U
M="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@
M("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M
M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L
M;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*
M("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@
M("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@
M("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I
M;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@
M("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D
M9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H
M)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC
M<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F
M:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N
M86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I
M;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E
M<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO
M9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@
M(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q
M=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@
M("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@
M("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E
M4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@
M("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@
M?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@
M("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G
M=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@
M97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?
M=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N
M:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@
M=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME
M9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`
M4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E
M;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@
M(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P
M(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'
M5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@
M("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]
M"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@
M;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@
M("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@
M("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@
M("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@
M("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@
M("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T
M(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@
M("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%
M3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@
M("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@
M("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@
M?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]
M"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2![
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&
M:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@
M(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R![
M"B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@
M("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F
M:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D
M(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@
M("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@
M;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@
M7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@
M(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@
M('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@
M("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@
M(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@
M("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@
M("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I
M(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@
M(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@
M("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q
M-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?
M/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@
M("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@
M9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E
M(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@
M:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@
M("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@
M86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S
M>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T
M96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@
M("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O
M=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@
M("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY
M("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N
M($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D
M(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S
M92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@
M("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L
M970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL
M97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L
M8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]
M"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN
M9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M"B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N
M86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@
M)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*
M("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!0
M05(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L
M;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H
M92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@
M("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@
M*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@
M("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G
M<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@
M("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@
M/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q
M=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E
M(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R
M;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@
M("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4[
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!0
M05(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N
M(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4
M:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?
M<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N
M.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2![
M"B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@
M("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE
M<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@
M("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@
M("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S
M97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@
M("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B
M/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#([
M"B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@
M("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@
M('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F
M:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<[
M"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@
M("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T
M.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O
M<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD
M)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA
M<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP
M9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L
M("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C
M)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N
M;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@
M0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@
M(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D[
M"B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M
M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M
M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@
M?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*
M("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@
M:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G
M;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@
M4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@
M("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R
M7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@
M("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@
M("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@
M("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R![
M"B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@
M("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@
M("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@
M("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@
M("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@
M<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*
M"B-L:6YE(#$P,3(*"E]?14Y$7U\*`````````"1&<F5E0E-$.B!S<F,O;&EB
M+V-S=2]S<&%R8S8T+V-R=&XN4RQV(#$N,2`R,#`Q+S$P+S(X(#`P.C(P.C,T
M(&]B<FEE;B!%>'`@)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````05P``````````````````(,)0_____P``````
M`````!!:0````````%OI`````````````````````0`````````!````````
M``$````````"-P`````````!`````````D$``````````0````````)/````
M``````$````````"7``````````/`````````\``````````#```````$!Q(
M``````````T``````!!6(``````````$```````0`<``````````!0``````
M$`\@``````````8``````!`%```````````*````````!10`````````"P``
M```````8`````````!4````````````````````#```````@PP``````````
M`@````````6@`````````!0`````````!P`````````7```````0%J@`````
M````!P``````$!5```````````@````````'"``````````)`````````!@`
M````<````0`````````!`````'````$``````````@````!O___^```````0
M%1``````;____P`````````!`````&____```````!`4-```````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````#__________P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````#``"`,&__YP$````!`````0````$````!`````0````,``*`P
M;__?`0````$````!`````0````$````!`````P``P#!O_]<!`````0````$`
M```!`````0````$````#``#@,&__SP$````!`````0````$````!`````0``
M``,``0`P;__'`0````$````!`````0````$````!`````P`!(#!O_[\!````
M`0````$````!`````0````$````#``%`,&__MP$````!`````0````$````!
M`````0````,``6`P;_^O`0````$````!`````0````$````!`````P`!@#!O
M_Z<!`````0````$````!`````0````$````#``&@,&__GP$````!`````0``
M``$````!`````0````,``<`P;_^7`0````$````!`````0````$````!````
M`P`!X#!O_X\!`````0````$````!`````0````$````#``(`,&__AP$````!
M`````0````$````!`````0````,``B`P;_]_`0````$````!`````0````$`
M```!`````P`"0#!O_W<!`````0````$````!`````0````$````#``)@,&__
M;P$````!`````0````$````!`````0````,``H`P;_]G`0````$````!````
M`0````$````!`````P`"H#!O_U\!`````0````$````!`````0````$````#
M``+`,&__5P$````!`````0````$````!`````0````,``N`P;_]/`0````$`
M```!`````0````$````!`````P`#`#!O_T<!`````0````$````!`````0``
M``$````#``,@,&__/P$````!`````0````$````!`````0````,``T`P;_\W
M`0````$````!`````0````$````!`````P`#8#!O_R\!`````0````$````!
M`````0````$````#``.`,&__)P$````!`````0````$````!`````0````,`
M`Z`P;_\?`0````$````!`````0````$````!`````P`#P#!O_Q<!`````0``
M``$````!`````0````$````#``/@,&__#P$````!`````0````$````!````
M`0````,`!``P;_\'`0````$````!`````0````$````!`````P`$(#!O_O\!
M`````0````$````!`````0````$````#``1`,&_^]P$````!`````0````$`
M```!`````0````,`!&`P;_[O`0````$````!`````0````$````!`````P`$
M@#!O_N<!`````0````$````!`````0````$````#``2@,&_^WP$````!````
M`0````$````!`````0````,`!,`P;_[7`0````$````!`````0````$````!
M`````P`$X#!O_L\!`````0````$````!`````0````$````#``4`,&_^QP$`
M```!`````0````$````!`````0````,`!2`P;_Z_`0````$````!`````0``
M``$````!`````P`%0#!O_K<!`````0````$````!`````0````$````#``5@
M,&_^KP$````!`````0````$````!`````0````,`!8`P;_ZG`0````$````!
M`````0````$````!`````P`%H#!O_I\!`````0````$````!`````0````$`
M```#``7`,&_^EP$````!`````0````$````!`````0````,`!>`P;_Z/`0``
M``$````!`````0````$````!`````P`&`#!O_H<!`````0````$````!````
M`0````$````#``8@,&_^?P$````!`````0````$````!`````0````,`!D`P
M;_YW`0````$````!`````0````$````!`````P`&8#!O_F\!`````0````$`
M```!`````0````$````#``:`,&_^9P$````!`````0````$````!`````0``
M``,`!J`P;_Y?`0````$````!`````0````$````!`````P`&P#!O_E<!````
M`0````$````!`````0````$````#``;@,&_^3P$````!`````0````$````!
M`````0````,`!P`P;_Y'`0````$````!`````0````$````!`````P`'(#!O
M_C\!`````0````$````!`````0````$````#``=`,&_^-P$````!`````0``
M``$````!`````0````,`!V`P;_XO`0````$````!`````0````$````!````
M`P`'@#!O_B<!`````0````$````!`````0````$````#``>@,&_^'P$````!
M`````0````$````!`````0````,`!\`P;_X7`0````$````!`````0````$`
M```!`````P`'X#!O_@\!`````0````$````!`````0````$``````````"#`
M.````````````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]C;VUM;VXO8W)T8G)A
M;F0N8RQV(#$N-"XR,"XQ(#(P,#<O,3(O,#8@,3,Z-#,Z-#,@:VEB($5X<"`D
M`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]S<&%R8S8T+V-R=#$N8RQV(#$N,3<@
M,C`P-B\Q,"\P."`P,CHU,#HS,R!K;6%C>2!%>'`@)`!'0T,Z("A'3E4I(#0N
M,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P
M-S`W,3D@(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)3
M1%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N9&%T80`N96A?
M9G)A;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0``````
M```"```````0`9`````````!D``````````5`````````````````````0``
M````````````$P````<``````````@``````$`&H`````````:@`````````
M&`````````````````````0``````````````"$````%``````````(`````
M`!`!P`````````'``````````SP````$```````````````(``````````0`
M```G````"P`````````"```````0!0`````````%``````````H@````!0``
M``$`````````"``````````8````+P````,``````````@``````$`\@````
M````#R`````````%%`````````````````````$``````````````#=O____
M``````````(``````!`4-````````!0T`````````-@````$````````````
M```"``````````(```!$;____@`````````"```````0%1`````````5$```
M```````P````!0````$`````````"```````````````4P````0`````````
M`@``````$!5`````````%4`````````!:`````0```````````````@`````
M````&````%T````$``````````(``````!`6J````````!:H````````!:``
M```$````%``````````(`````````!@```!G`````0`````````&```````0
M'$@````````<2``````````<````````````````````!```````````````
M;0````$`````````!@``````$!R`````````'(`````````YH```````````
M`````````"```````````````',````!``````````8``````!!6(```````
M`%8@`````````!0````````````````````$``````````````!Y`````0``
M```````"```````05C@```````!6.````````&!,````````````````````
M"```````````````@0````$``````````P``````(,``````````P```````
M````,`````````````````````@``````````````(<````!``````````(`
M`````"#`,````````,`P``````````0````````````````````$````````
M``````"1````!@`````````#```````@P#@```````#`.`````````(`````
M!0``````````````"``````````0````F@````$``````````P``````(,(X
M````````PC@`````````$`````````````````````@``````````````*$`
M```!``````````,``````"#"2````````,)(`````````!``````````````
M```````(``````````````"H`````0`````````#```````@PE@```````#"
M6``````````(````````````````````"```````````````8@````$`````
M````!P``````(,,`````````PP`````````(`````````````````````0``
M````````(````*T````!``````````,``````"#+`````````,L`````````
M``@````````````````````(``````````@```"R````"``````````#````
M```@RQ````````#+$`````````3H````````````````````$```````````
M````MP````$`````````````````````````````RQ`````````!6P``````
M``````````````$```````````````$````#````````````````````````
F`````,QK`````````,`````````````````````!````````````
